@@ -27,15 +27,15 @@ from .paginator import (
     ListTablesPaginator,
 )
 from .type_defs import (
-    CancelStatementResponseResponseTypeDef,
-    DescribeStatementResponseResponseTypeDef,
-    DescribeTableResponseResponseTypeDef,
-    ExecuteStatementOutputResponseTypeDef,
-    GetStatementResultResponseResponseTypeDef,
-    ListDatabasesResponseResponseTypeDef,
-    ListSchemasResponseResponseTypeDef,
-    ListStatementsResponseResponseTypeDef,
-    ListTablesResponseResponseTypeDef,
+    CancelStatementResponseTypeDef,
+    DescribeStatementResponseTypeDef,
+    DescribeTableResponseTypeDef,
+    ExecuteStatementOutputTypeDef,
+    GetStatementResultResponseTypeDef,
+    ListDatabasesResponseTypeDef,
+    ListSchemasResponseTypeDef,
+    ListStatementsResponseTypeDef,
+    ListTablesResponseTypeDef,
     SqlParameterTypeDef,
 )
 
@@ -67,7 +67,7 @@ class Exceptions:
 
 class RedshiftDataAPIServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html)
     """
 
@@ -78,24 +78,24 @@ class RedshiftDataAPIServiceClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#can_paginate)
         """
 
-    def cancel_statement(self, *, Id: str) -> CancelStatementResponseResponseTypeDef:
+    def cancel_statement(self, *, Id: str) -> CancelStatementResponseTypeDef:
         """
         Cancels a running query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#cancel_statement)
         """
 
-    def describe_statement(self, *, Id: str) -> DescribeStatementResponseResponseTypeDef:
+    def describe_statement(self, *, Id: str) -> DescribeStatementResponseTypeDef:
         """
         Describes the details about a specific instance when a query was run by the
         Amazon Redshift Data API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_statement)
         """
 
@@ -111,11 +111,11 @@ class RedshiftDataAPIServiceClient:
         Schema: str = None,
         SecretArn: str = None,
         Table: str = None
-    ) -> DescribeTableResponseResponseTypeDef:
+    ) -> DescribeTableResponseTypeDef:
         """
         Describes the detailed information about a table from metadata in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_table)
         """
 
@@ -130,12 +130,12 @@ class RedshiftDataAPIServiceClient:
         SecretArn: str = None,
         StatementName: str = None,
         WithEvent: bool = None
-    ) -> ExecuteStatementOutputResponseTypeDef:
+    ) -> ExecuteStatementOutputTypeDef:
         """
         Runs an SQL statement, which can be data manipulation language (DML) or data
         definition language (DDL).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#execute_statement)
         """
 
@@ -149,17 +149,17 @@ class RedshiftDataAPIServiceClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#generate_presigned_url)
         """
 
     def get_statement_result(
         self, *, Id: str, NextToken: str = None
-    ) -> GetStatementResultResponseResponseTypeDef:
+    ) -> GetStatementResultResponseTypeDef:
         """
         Fetches the temporarily cached result of an SQL statement.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#get_statement_result)
         """
 
@@ -172,11 +172,11 @@ class RedshiftDataAPIServiceClient:
         MaxResults: int = None,
         NextToken: str = None,
         SecretArn: str = None
-    ) -> ListDatabasesResponseResponseTypeDef:
+    ) -> ListDatabasesResponseTypeDef:
         """
         List the databases in a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_databases)
         """
 
@@ -191,11 +191,11 @@ class RedshiftDataAPIServiceClient:
         NextToken: str = None,
         SchemaPattern: str = None,
         SecretArn: str = None
-    ) -> ListSchemasResponseResponseTypeDef:
+    ) -> ListSchemasResponseTypeDef:
         """
         Lists the schemas in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_schemas)
         """
 
@@ -207,11 +207,11 @@ class RedshiftDataAPIServiceClient:
         RoleLevel: bool = None,
         StatementName: str = None,
         Status: StatusStringType = None
-    ) -> ListStatementsResponseResponseTypeDef:
+    ) -> ListStatementsResponseTypeDef:
         """
         List of SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_statements)
         """
 
@@ -227,18 +227,18 @@ class RedshiftDataAPIServiceClient:
         SchemaPattern: str = None,
         SecretArn: str = None,
         TablePattern: str = None
-    ) -> ListTablesResponseResponseTypeDef:
+    ) -> ListTablesResponseTypeDef:
         """
         List the tables in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_tables)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_table"]) -> DescribeTablePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
         """
 
@@ -247,34 +247,34 @@ class RedshiftDataAPIServiceClient:
         self, operation_name: Literal["get_statement_result"]
     ) -> GetStatementResultPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_databases"]) -> ListDatabasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schemas"]) -> ListSchemasPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_statements"]) -> ListStatementsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
         """
